==> QLC%2B_4.12.6.tar.gz: qlcplus-QLC-_4.12.6/webaccess/src/webaccess_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="169"/>
        <source>Loading project...</source>
        <translation>Cargando proyecto...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="205"/>
        <source>Fixture stored and loaded</source>
        <translation>Fixture guardado y cargado</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="396"/>
        <source>Username and password are required fields.</source>
        <translation>Nombre de usuario y contraseña son campos obligatorios.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="402"/>
        <location filename="webaccess.cpp" line="427"/>
        <source>User level has to be a positive integer.</source>
        <translation>El nivel de usuario tiene que ser un entero positivo.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="421"/>
        <source>Username is required.</source>
        <translation>Nombre de usuario es obligatorio.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="439"/>
        <source>Error while saving passwords file.</source>
        <translation>Error al guardar el archivo de contraseña.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="454"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>La configuración de red ha cambiado. Reiniciar para aplicar los cambios.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="473"/>
        <source>Autostart configuration changed</source>
        <translation>La configuración de inicio automático ha cambiado</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="822"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Widget no soportado (todavía) para acceso web</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="873"/>
        <location filename="webaccess.cpp" line="925"/>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1088"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1120"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1121"/>
        <source>Fade In</source>
        <translation>Fade In</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1122"/>
        <source>Fade Out</source>
        <translation>Fade Out</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1123"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1124"/>
        <source>Notes</source>
        <translation>Notas</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1360"/>
        <source>Load project</source>
        <translation>Cargar proyecto</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1362"/>
        <source>Simple Desk</source>
        <translation>Mesa Simple</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1364"/>
        <source>Configuration</source>
        <translation>Configuración</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Passthrough</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Cargar fixture</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation>Nivel de acceso</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation>Dejar en blanco para no cambiar</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation>Sólo Consola Virtual</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation>Consola Virtual y Mesa Simple</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation>Todo</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation>Cambiar</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation>Borrar usuario</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation>Nuevo nombre de usuario...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation>Nueva contraseña...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation>Nombre de usuario y contraseña son campos obligatorios.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation>Añadir usuario</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation>Nota: si no hay al menos un usuario con nivel de acceso &quot;Todo&quot; en la lista de autorización, se desactivará.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="323"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="332"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="340"/>
        <source>Universes configuration</source>
        <translation>Configuración de universos</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="347"/>
        <source>Audio configuration</source>
        <translation>Configuración de audio</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="355"/>
        <source>User loaded fixtures</source>
        <translation>Fixtures cargados por el usuario</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="364"/>
        <source>Authorized users</source>
        <translation>Usuarios autorizados</translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="101"/>
        <source>Network interface: </source>
        <translation>Interfaz de red:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="106"/>
        <source>Access point name (SSID): </source>
        <translation>Nombre de punto de acceso (SSID): </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="108"/>
        <source>WPA-PSK Password: </source>
        <translation>Contraseña WPA-PSK: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="113"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dinámico (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="115"/>
        <source>Static</source>
        <translation>Estático</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="119"/>
        <source>IP Address: </source>
        <translation>Dirección IP:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="121"/>
        <source>Netmask: </source>
        <translation>Máscara de red:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="123"/>
        <source>Gateway: </source>
        <translation>Puerta de enlace:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="126"/>
        <location filename="webaccessnetwork.cpp" line="344"/>
        <source>Apply changes</source>
        <translation>Aplicar cambios</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="327"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="333"/>
        <source>Network configuration</source>
        <translation>Configuración de red</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="338"/>
        <source>Project autostart</source>
        <translation>Inicio automático de proyecto</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>No project</source>
        <translation>Ningún proyecto</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Use current project</source>
        <translation>Usar el proyecto actual</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="349"/>
        <source>Shutdown</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Página anterior</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Página siguiente</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Reiniciar universo</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Universo</translation>
    </message>
</context>
</TS>

==> QLC%2B_4.14.0.tar.gz: qlcplus-QLC-_4.14.0/webaccess/src/webaccess_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="172"/>
        <source>Loading project...</source>
        <translation>Cargando proyecto...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="208"/>
        <source>Fixture stored and loaded</source>
        <translation>Fixture guardado y cargado</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="408"/>
        <source>Username and password are required fields.</source>
        <translation>Nombre de usuario y contraseña son campos obligatorios.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="414"/>
        <location filename="webaccess.cpp" line="439"/>
        <source>User level has to be a positive integer.</source>
        <translation>El nivel de usuario tiene que ser un entero positivo.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="433"/>
        <source>Username is required.</source>
        <translation>Nombre de usuario es obligatorio.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="451"/>
        <source>Error while saving passwords file.</source>
        <translation>Error al guardar el archivo de contraseña.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="466"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>La configuración de red ha cambiado. Reiniciar para aplicar los cambios.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="468"/>
        <source>An error occurred while updating the network configuration.</source>
        <translation>Se produjo un error al actualizar la configuración de la red.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="484"/>
        <source>Wi-Fi hotspot successfully activated.</source>
        <translation>Punto de acceso Wi-Fi activado exitosamente.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="486"/>
        <source>An error occurred while creating a Wi-Fi hotspot.</source>
        <translation>Se produjo un error al crear un punto de acceso Wi-Fi.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="491"/>
        <source>Wi-Fi hotspot successfully deactivated.</source>
        <translation>Punto de acceso Wi-Fi desactivado exitosamente.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="507"/>
        <source>Autostart configuration changed</source>
        <translation>La configuración de inicio automático ha cambiado</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1014"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Widget no soportado (todavía) para acceso web</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1440"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1643"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1644"/>
        <source>Fade In</source>
        <translation>Fade In</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1645"/>
        <source>Fade Out</source>
        <translation>Fade Out</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1646"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1647"/>
        <source>Notes</source>
        <translation>Notas</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2076"/>
        <source>Color 2 Reset</source>
        <translation>Color Reset 2</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2085"/>
        <source>Color 3 Reset</source>
        <translation>Color Reset 3</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2094"/>
        <source>Color 4 Reset</source>
        <translation>Color Reset 4</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2103"/>
        <source>Color 5 Reset</source>
        <translation>Color Reset 5</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2345"/>
        <source>Load project</source>
        <translation>Cargar proyecto</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2347"/>
        <source>Simple Desk</source>
        <translation>Mesa Simple</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2349"/>
        <source>Configuration</source>
        <translation>Configuración</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Passthrough</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Cargar fixture</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation>Nivel de acceso</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation>Dejar en blanco para no cambiar</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation>Sólo Consola Virtual</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation>Consola Virtual y Mesa Simple</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation>Todo</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation>Cambiar</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation>Borrar usuario</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation>Nuevo nombre de usuario...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation>Nueva contraseña...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation>Nombre de usuario y contraseña son campos obligatorios.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation>Añadir usuario</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation>Nota: si no hay al menos un usuario con nivel de acceso &quot;Todo&quot; en la lista de autorización, se desactivará.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="322"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="331"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="339"/>
        <source>Universes configuration</source>
        <translation>Configuración de universos</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="346"/>
        <source>Audio configuration</source>
        <translation>Configuración de audio</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="354"/>
        <source>User loaded fixtures</source>
        <translation>Fixtures cargados por el usuario</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="363"/>
        <source>Authorized users</source>
        <translation>Usuarios autorizados</translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="114"/>
        <source>Wi-Fi Hotspot</source>
        <translation>Punto de acceso WiFi</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="118"/>
        <location filename="webaccessnetwork.cpp" line="136"/>
        <source>Access point name (SSID): </source>
        <translation>Nombre de punto de acceso (SSID): </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="120"/>
        <location filename="webaccessnetwork.cpp" line="138"/>
        <source>WPA-PSK Password: </source>
        <translation>Contraseña WPA-PSK: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="124"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="125"/>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="130"/>
        <source>Network interface</source>
        <translation>Interfaz de red</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="144"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dinámico (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="146"/>
        <source>Static</source>
        <translation>Estático</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="151"/>
        <source>IP Address: </source>
        <translation>Dirección IP: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="153"/>
        <source>Netmask: </source>
        <translation>Máscara de red: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="155"/>
        <source>Gateway: </source>
        <translation>Puerta de enlace: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="158"/>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Apply changes</source>
        <translation>Aplicar cambios</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="326"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="332"/>
        <source>Network configuration</source>
        <translation>Configuración de red</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="337"/>
        <source>Project autostart</source>
        <translation>Inicio automático de proyecto</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="341"/>
        <source>No project</source>
        <translation>Ningún proyecto</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>Use current project</source>
        <translation>Usar el proyecto actual</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="347"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Shutdown</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Página anterior</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Página siguiente</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Reiniciar universo</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Universo</translation>
    </message>
</context>
</TS>
